@@ -1,20 +1,19 @@
 # ---------------------------------------------------------------------
 # IMPORTS
 
-import aiohttp
-import requests
 import re
 import html
+import json
 from enum import Enum
+import aiohttp
+import requests
 from fake_useragent import UserAgent
 
-
 # ---------------------------------------------------------------------
 
+
 class SearchModifiers(Enum):
     NONE = ""
-    # INCLUDE_DLC is left, but should NO LONGER make a difference. HowLongToBeat re-added DLC in standard requests
-    INCLUDE_DLC = "show_dlc"
     # ISOLATE_DLC shows only DLC in the search result
     ISOLATE_DLC = "only_dlc"
     # HIDE_DLC hide DLCs in the search result
@@ -23,11 +22,69 @@ class SearchModifiers(Enum):
 
 class HTMLRequests:
     BASE_URL = 'https://howlongtobeat.com/'
-    SEARCH_URL = BASE_URL + "search_results"
-    GAME_URL = BASE_URL + "game?id="
+    REFERER_HEADER = BASE_URL
+    SEARCH_URL = BASE_URL + "api/search"
+    GAME_URL = BASE_URL + "game"
 
     @staticmethod
-    def send_web_request(game_name: str, search_modifiers: SearchModifiers = SearchModifiers.NONE, page: int = 1):
+    def get_search_request_headers():
+        """
+        Generate the headers for the search request
+        @return: The headers object for the request
+        """
+        ua = UserAgent()
+        headers = {
+            'content-type': 'application/json',
+            'accept': '*/*',
+            'User-Agent': ua.random,
+            'referer': HTMLRequests.REFERER_HEADER
+        }
+        return headers
+
+    @staticmethod
+    def get_search_request_data(game_name: str, search_modifiers: SearchModifiers, page: int):
+        """
+        Generate the data payload for the search request
+        @param game_name: The name of the game to search
+        @param search_modifiers: The search modifiers to use in the search
+        @param page: The page to search
+        @return: The request (data) payload object for the request
+        """
+        payload = {
+            'searchType': "games",
+            'searchTerms': game_name.split(),
+            'searchPage': page,
+            'size': 20,
+            'searchOptions': {
+                'games': {
+                    'userId': 0,
+                    'platform': "",
+                    'sortCategory': "popular",
+                    'rangeCategory': "main",
+                    'rangeTime': {
+                        'min': 0,
+                        'max': 0
+                    },
+                    'gameplay': {
+                        'perspective': "",
+                        'flow': "",
+                        'genre': ""
+                    },
+                    'modifier': search_modifiers.value,
+                },
+                'users': {
+                    'sortCategory': "postcount"
+                },
+                'filter': "",
+                'sort': 0,
+                'randomizer': 0
+            }
+        }
+        return json.dumps(payload)
+
+    @staticmethod
+    def send_web_request(game_name: str, search_modifiers: SearchModifiers = SearchModifiers.NONE,
+                         page: int = 1):
         """
         Function that search the game using a normal request
         @param game_name: The original game name received as input
@@ -35,41 +92,17 @@ class HTMLRequests:
         @param page: The page to explore of the research, unknown if this is actually used
         @return: The HTML code of the research if the request returned 200(OK), None otherwise
         """
-        ua = UserAgent()
-        params = {
-            'page': str(page)
-        }
-        headers = {
-            'content-type': 'application/x-www-form-urlencoded',
-            'accept': '*/*',
-            'User-Agent': ua.random,
-            'origin': 'https://howlongtobeat.com',
-            'referer': 'https://howlongtobeat.com/'
-        }
-        payload = {
-            'queryString': game_name,
-            't': 'games',
-            'sorthead': 'popular',
-            'sortd': 'Normal Order',
-            'plat': '',
-            'length_type': 'main',
-            'length_min': '',
-            'length_max': '',
-            'detail': search_modifiers.value,
-            'v': '',
-            'f': '',
-            'g': '',
-            'randomize': '0'
-        }
+        headers = HTMLRequests.get_search_request_headers()
+        payload = HTMLRequests.get_search_request_data(game_name, search_modifiers, page)
         # Make the post request and return the result if is valid
-        resp = requests.post(HTMLRequests.SEARCH_URL, params=params, headers=headers, data=payload)
-        if resp is not None and resp.status_code == 200:
+        resp = requests.post(HTMLRequests.SEARCH_URL, headers=headers, data=payload)
+        if resp.status_code == 200:
             return resp.text
-        else:
-            return None
+        return None
 
     @staticmethod
-    async def send_async_web_request(game_name: str, search_modifiers: SearchModifiers = SearchModifiers.NONE, page: int = 1):
+    async def send_async_web_request(game_name: str, search_modifiers: SearchModifiers = SearchModifiers.NONE,
+                                     page: int = 1):
         """
         Function that search the game using an async request
         @param game_name: The original game name received as input
@@ -77,39 +110,14 @@ class HTMLRequests:
         @param page: The page to explore of the research, unknown if this is actually used
         @return: The HTML code of the research if the request returned 200(OK), None otherwise
         """
-        ua = UserAgent()
-        params = {
-            'page': str(page)
-        }
-        headers = {
-            'content-type': 'application/x-www-form-urlencoded',
-            'accept': '*/*',
-            'User-Agent': ua.random,
-            'origin': 'https://howlongtobeat.com',
-            'referer': 'https://howlongtobeat.com/'
-        }
-        payload = {
-            'queryString': game_name,
-            't': 'games',
-            'sorthead': 'popular',
-            'sortd': 'Normal Order',
-            'plat': '',
-            'length_type': 'main',
-            'length_min': '',
-            'length_max': '',
-            'detail': search_modifiers.value,
-            'v': '',
-            'f': '',
-            'g': '',
-            'randomize': '0'
-        }
+        headers = HTMLRequests.get_search_request_headers()
+        payload = HTMLRequests.get_search_request_data(game_name, search_modifiers, page)
         # Make the post request and return the result if is valid
         async with aiohttp.ClientSession() as session:
-            async with session.post(HTMLRequests.SEARCH_URL, params=params, headers=headers, data=payload) as resp:
+            async with session.post(HTMLRequests.SEARCH_URL, headers=headers, data=payload) as resp:
                 if resp is not None and str(resp.status) == "200":
                     return await resp.text()
-                else:
-                    return None
+                return None
 
     @staticmethod
     def __cut_game_title(game_title: str):
@@ -124,11 +132,36 @@ class HTMLRequests:
         if game_title is None or len(game_title) == 0:
             return None
 
-        title = re.search("<title>([\w\W]*)<\/title>", game_title)
+        title = re.search("<title>(.*)<\/title>", game_title)
         # The position of start and end of this method may change if the website change
         cut_title = str(html.unescape(title.group(1)[12:-17]))
         return cut_title
 
+    @staticmethod
+    def get_title_request_parameters(game_id: int):
+        """
+        Generate the parameters for the search request
+        @param game_id: The game id to search in HLTB
+        @return: The parameters object for the request
+        """
+        params = {
+            'id': str(game_id)
+        }
+        return params
+
+    @staticmethod
+    def get_title_request_headers():
+        """
+        Generate the headers for the search request
+        @return: The headers object for the request
+        """
+        ua = UserAgent()
+        headers = {
+            'User-Agent': ua.random,
+            'referer': HTMLRequests.REFERER_HEADER
+        }
+        return headers
+
     @staticmethod
     def get_game_title(game_id: int):
         """
@@ -137,14 +170,8 @@ class HTMLRequests:
         @return: The game title from the given id
         """
 
-        ua = UserAgent()
-        params = {
-            'id': str(game_id)
-        }
-        headers = {
-            'User-Agent': ua.random,
-            'referer': 'https://howlongtobeat.com/'
-        }
+        params = HTMLRequests.get_title_request_parameters(game_id)
+        headers = HTMLRequests.get_title_request_headers()
 
         # Request and extract title
         contents = requests.get(HTMLRequests.GAME_URL, params=params, headers=headers)
@@ -158,14 +185,8 @@ class HTMLRequests:
         @return: The game title from the given id
         """
 
-        ua = UserAgent()
-        params = {
-            'id': str(game_id)
-        }
-        headers = {
-            'User-Agent': ua.random,
-            'referer': 'https://howlongtobeat.com/'
-        }
+        params = HTMLRequests.get_title_request_parameters(game_id)
+        headers = HTMLRequests.get_title_request_headers()
 
         # Request and extract title
         async with aiohttp.ClientSession() as session:
@@ -173,5 +194,4 @@ class HTMLRequests:
                 if resp is not None and str(resp.status) == "200":
                     text = await resp.text()
                     return HTMLRequests.__cut_game_title(text)
-                else:
-                    return None
+                return None
