@@ -1,9 +1,8 @@
 # ---------------------------------------------------------------------
 # IMPORTS
 
-from .HTMLResultParser import HTMLResultParser
 from .HTMLRequests import HTMLRequests, SearchModifiers
-
+from .JSONResultParser import JSONResultParser
 
 # ---------------------------------------------------------------------
 
@@ -25,8 +24,6 @@ class HowLongToBeat:
         """
         self.minimum_similarity = input_minimum_similarity
 
-    # body of the constructor
-
     # ------------------------------------------
     # (Standard) Search functions using game name
     # ------------------------------------------
@@ -37,7 +34,7 @@ class HowLongToBeat:
         Function that search the game using an async request
         @param game_name: The original game name received as input
         @param search_modifiers: The "Modifiers" list in "Search Options", allow to show/isolate/hide DLCs
-        @param similarity_case_sensitive: If the similarity check between names should be case sensitive (default true)
+        @param similarity_case_sensitive: If the similarity check between names should be case-sensitive (default true)
         @return: A list of possible games (or None in case of wrong parameter or failed request)
         """
         if game_name is None or len(game_name) == 0:
@@ -45,8 +42,7 @@ class HowLongToBeat:
         html_result = await HTMLRequests.send_async_web_request(game_name, search_modifiers)
         if html_result is not None:
             return self.__parse_web_result(game_name, html_result, None, similarity_case_sensitive)
-        else:
-            return None
+        return None
 
     def search(self, game_name: str, search_modifiers: SearchModifiers = SearchModifiers.NONE,
                similarity_case_sensitive: bool = True):
@@ -54,7 +50,7 @@ class HowLongToBeat:
         Function that search the game using a normal request
         @param game_name: The original game name received as input
         @param search_modifiers: The "Modifiers" list in "Search Options", allow to show/isolate/hide DLCs
-        @param similarity_case_sensitive: If the similarity check between names should be case sensitive (default true)
+        @param similarity_case_sensitive: If the similarity check between names should be case-sensitive (default true)
         @return: A list of possible games (or None in case of wrong parameter or failed request)
         """
         if game_name is None or len(game_name) == 0:
@@ -62,8 +58,7 @@ class HowLongToBeat:
         html_result = HTMLRequests.send_web_request(game_name, search_modifiers)
         if html_result is not None:
             return self.__parse_web_result(game_name, html_result, None, similarity_case_sensitive)
-        else:
-            return None
+        return None
 
     # ------------------------------------------
     # Search functions using game id
@@ -72,8 +67,7 @@ class HowLongToBeat:
     async def async_search_from_id(self, game_id: int):
         """
         Function that search the game using an async request
-        To re-use code, i extract the game name and search game by name, picking only the game with the same id
-        Otherwise a new parser is necessary, and is probably not worth to maintain 2 different html parsers
+        To re-use code, I extract the game name and search game by name, picking only the game with the same id
         Remember that this function use 2 requests: one to get the game title and one to get game data
         @param game_id: The game id to get data
         @return: The game data (single HowLongToBeatEntry object) or None in case of error
@@ -87,17 +81,13 @@ class HowLongToBeat:
                 result_list = self.__parse_web_result(game_title, html_result, game_id)
                 if result_list is None or len(result_list) == 0 or len(result_list) > 1:
                     return None
-                else:
-                    return result_list[0]
-            else:
-                return None
-        else:
+                return result_list[0]
             return None
+        return None
 
     def search_from_id(self, game_id: int):
         """
-        To re-use code, i extract the game name and search game by name, picking only the game with the same id
-        Otherwise a new parser is necessary, and is probably not worth to maintain 2 different html parsers
+        To re-use code, I extract the game name and search game by name, picking only the game with the same id
         Remember that this function use 2 requests: one to get the game title and one to get game data
         @param game_id: The game id to get data
         @return: The game data (single HowLongToBeatEntry object) None in case of error
@@ -111,12 +101,9 @@ class HowLongToBeat:
                 result_list = self.__parse_web_result(game_title, html_result, game_id)
                 if result_list is None or len(result_list) == 0 or len(result_list) > 1:
                     return None
-                else:
-                    return result_list[0]
-            else:
-                return None
-        else:
+                return result_list[0]
             return None
+        return None
 
     # ------------------------------------------
     # Private utils functions
@@ -132,12 +119,12 @@ class HowLongToBeat:
         @return: A list of possible games
         """
         if game_id is None:
-            parser = HTMLResultParser(game_name, HTMLRequests.GAME_URL, self.minimum_similarity, game_id,
+            parser = JSONResultParser(game_name, HTMLRequests.GAME_URL, self.minimum_similarity, game_id,
                                       similarity_case_sensitive)
         else:
             # If the search is by id, ignore class minimum_similarity and set it to 0.0
-            # The result is filter by ID anyway, so the similarity shouldn't count too much
+            # The result is filtered by ID anyway, so the similarity shouldn't count too much
             # Also ignore similarity_case_sensitive and leave default value
-            parser = HTMLResultParser(game_name, HTMLRequests.GAME_URL, 0.0, game_id)
-        parser.feed(html_result)
+            parser = JSONResultParser(game_name, HTMLRequests.GAME_URL, 0.0, game_id)
+        parser.parse_json_result(html_result)
         return parser.results
